import 'dart:async';

import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:petitbac/config/default_settings.dart';
import 'package:petitbac/cubit/settings_cubit.dart';
import 'package:provider/provider.dart';

import 'package:petitbac/utils/color_extensions.dart';
import 'package:petitbac/utils/game_utils.dart';
import 'package:petitbac/provider/data.dart';

class MiniGame extends StatelessWidget {
  const MiniGame({
    super.key,
    required this.backgroundColor,
    required this.borderWidth,
  });

  final Color backgroundColor;
  final double borderWidth;

  static Timer? _timer;
  static int _countdownStart = 0;

  void dispose() {
    _timer?.cancel();
  }

  Future<void> startTimer(Data myProvider, int timerDuration) async {
    const oneSec = Duration(seconds: 1);
    if (_timer != null) {
      dispose();
    }
    _countdownStart = timerDuration;
    myProvider.updateCountdown(_countdownStart);
    _timer = Timer.periodic(
      oneSec,
      (Timer timer) {
        if (_countdownStart < 0) {
          timer.cancel();
        } else {
          _countdownStart--;
          myProvider.updateCountdown(_countdownStart);
        }
      },
    );
  }

  Future<void> startMiniGame(Data myProvider, int timerDuration) async {
    if (myProvider.countdown <= 0) {
      GameUtils.pickCategory(myProvider);
      GameUtils.pickLetter(myProvider);
      startTimer(myProvider, timerDuration);
    }
  }

  @override
  Widget build(BuildContext context) {
    final Data myProvider = Provider.of<Data>(context);

    final Color borderColor = backgroundColor.darken();

    Color countDownColor = Colors.black;
    if (myProvider.countdown == 0) {
      countDownColor = Colors.red;
    }

    return Column(
      mainAxisSize: MainAxisSize.min,
      mainAxisAlignment: MainAxisAlignment.center,
      children: [
        Container(
          margin: EdgeInsets.all(borderWidth),
          padding: EdgeInsets.all(borderWidth),
          decoration: BoxDecoration(
            color: backgroundColor,
            borderRadius: BorderRadius.circular(borderWidth),
            border: Border.all(
              color: borderColor,
              width: borderWidth,
            ),
          ),
          child: BlocBuilder<SettingsCubit, SettingsState>(
            builder: (context, settingsSate) {
              return TextButton(
                onPressed: (myProvider.countdown >= 0)
                    ? null
                    : () => startMiniGame(myProvider,
                        settingsSate.timerValue ?? DefaultSettings.defaultTimerValue),
                child: Text(
                  (myProvider.countdown >= 0) ? myProvider.countdown.toString() : '🎲',
                  textAlign: TextAlign.center,
                  style: TextStyle(
                    fontSize: 50,
                    fontWeight: FontWeight.w600,
                    color: countDownColor,
                  ),
                ),
              );
            },
          ),
        ),
      ],
    );
  }
}
