import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

import 'package:petitbac/ui/widgets/previous_letter.dart';
import 'package:petitbac/utils/color_extensions.dart';
import 'package:petitbac/utils/game_utils.dart';
import 'package:petitbac/provider/data.dart';

class PickedLetter extends StatelessWidget {
  const PickedLetter({
    super.key,
    required this.backgroundColor,
    required this.borderWidth,
  });

  final Color backgroundColor;
  final double borderWidth;

  Container mainLetterButtonContainer(
    Data myProvider,
    Color backgroundColor,
    double borderWidth,
  ) {
    final Color borderColor = backgroundColor.darken();

    return Container(
      margin: EdgeInsets.all(borderWidth),
      padding: EdgeInsets.all(borderWidth),
      decoration: BoxDecoration(
        color: backgroundColor,
        borderRadius: BorderRadius.circular(borderWidth),
        border: Border.all(
          color: borderColor,
          width: borderWidth,
        ),
      ),
      child: TextButton(
        onPressed: () => GameUtils.pickLetter(myProvider),
        child: Text(
          myProvider.letter == '' ? "🔀" : myProvider.letter,
          style: const TextStyle(
            fontSize: 40,
            fontWeight: FontWeight.w600,
            color: Colors.black,
          ),
        ),
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    final Data myProvider = Provider.of<Data>(context);

    const int previousLettersCountToShow = 3;

    final List<Widget> cells = [];

    // Add previous letters blocks
    for (var i = 0; i < previousLettersCountToShow; i++) {
      final int position = previousLettersCountToShow - i;
      cells.add(TableCell(
        verticalAlignment: TableCellVerticalAlignment.middle,
        child: PreviousLetter(
          letter: myProvider.recentlyPickedLetter(position),
          position: position,
          displayed: true,
        ),
      ));
    }

    // Add current letter block
    cells.add(TableCell(
      verticalAlignment: TableCellVerticalAlignment.middle,
      child: mainLetterButtonContainer(myProvider, backgroundColor, borderWidth),
    ));

    // Pad with empty blocks to keep symetrical layout
    for (var i = 0; i < previousLettersCountToShow; i++) {
      cells.add(TableCell(
        verticalAlignment: TableCellVerticalAlignment.middle,
        child: PreviousLetter(
          letter: myProvider.recentlyPickedLetter(i + 1),
          position: i + 1,
          displayed: false,
        ),
      ));
    }

    return Container(
      margin: const EdgeInsets.all(2),
      padding: const EdgeInsets.all(2),
      child: Table(
        defaultColumnWidth: const IntrinsicColumnWidth(),
        children: [
          TableRow(children: cells),
        ],
      ),
    );
  }
}
