import 'package:easy_localization/easy_localization.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import 'package:petitbac/config/default_settings.dart';
import 'package:petitbac/cubit/settings_cubit.dart';
import 'package:petitbac/ui/widgets/theme_card.dart';
import 'package:unicons/unicons.dart';

class SettingsForm extends StatefulWidget {
  const SettingsForm({super.key});

  @override
  State<SettingsForm> createState() => _SettingsFormState();
}

class _SettingsFormState extends State<SettingsForm> {
  int timerValue = DefaultSettings.defaultTimerValue;

  List<bool> _selectedTimerValue = [];

  @override
  void dispose() {
    super.dispose();
  }

  @override
  void didChangeDependencies() {
    SettingsCubit settings = BlocProvider.of<SettingsCubit>(context);

    timerValue = settings.getTimerValue();

    _selectedTimerValue =
        DefaultSettings.allowedTimerValues.map((e) => (e == timerValue)).toList();

    super.didChangeDependencies();
  }

  @override
  Widget build(BuildContext context) {
    void saveSettings() {
      BlocProvider.of<SettingsCubit>(context).setValues(
        timerValue: timerValue,
      );
    }

    return Column(
      mainAxisAlignment: MainAxisAlignment.start,
      crossAxisAlignment: CrossAxisAlignment.start,
      mainAxisSize: MainAxisSize.max,
      children: <Widget>[
        // Light/dark theme
        Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: <Widget>[
            const Text('settings_label_theme').tr(),
            const Row(
              mainAxisAlignment: MainAxisAlignment.end,
              crossAxisAlignment: CrossAxisAlignment.center,
              children: [
                ThemeCard(
                  mode: ThemeMode.system,
                  icon: UniconsLine.cog,
                ),
                ThemeCard(
                  mode: ThemeMode.light,
                  icon: UniconsLine.sun,
                ),
                ThemeCard(
                  mode: ThemeMode.dark,
                  icon: UniconsLine.moon,
                )
              ],
            ),
          ],
        ),

        const SizedBox(height: 16),

        // Timer value
        Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            const Text('settings_label_timer_value').tr(),
            ToggleButtons(
              onPressed: (int index) {
                setState(() {
                  timerValue = DefaultSettings.allowedTimerValues[index];
                  for (int i = 0; i < _selectedTimerValue.length; i++) {
                    _selectedTimerValue[i] = i == index;
                  }
                });
                saveSettings();
              },
              borderRadius: const BorderRadius.all(Radius.circular(8)),
              constraints: const BoxConstraints(minHeight: 30.0, minWidth: 30.0),
              isSelected: _selectedTimerValue,
              children:
                  DefaultSettings.allowedTimerValues.map((e) => Text(e.toString())).toList(),
            ),
          ],
        ),
      ],
    );
  }
}
